@@ -38,7 +38,8 @@ from parce.registry import register
 
 register("parce.lang.bash.Bash.root",
     name = "Bash",
-    desc = "Bash and other shell language",
+    desc = "Bash shell language",
+    section = "Shell",
     aliases = ["sh"],
     filenames = [("*.sh", .7), ("*.bash", 1)],
     mimetypes = [("text/x-shellscript", 1)],
@@ -48,6 +49,7 @@ register("parce.lang.bash.Bash.root",
 register("parce.lang.c.C.root",
     name = "C",
     desc = "C/C++ programming language",
+    section = "Programming",
     aliases = ["c", "cpp"],
     filenames = [("*.[ch]", .7), ("*.[ch]pp", .7), ("*.cc", .7), ("*.hh", .7)],
     mimetypes = [("text/x-c", 1)],
@@ -57,6 +59,7 @@ register("parce.lang.c.C.root",
 register("parce.lang.css.Css.root",
     name = "CSS",
     desc = "Cascading Style Sheet",
+    section = "Markup",
     filenames = [("*.css", 1)],
     mimetypes = [("text/css", 1)],
     guesses = [(r'\b@media\b', 0.5), (r'\bdiv\b', 0.1), (r'\bbody\s*\{', 0.4)],
@@ -65,6 +68,7 @@ register("parce.lang.css.Css.root",
 register("parce.lang.csv.Csv.root",
     name = "CSV",
     desc = "Comma-separated values",
+    section = "Other",
     filenames = [("*.csv", 1)],
     mimetypes = [("text/csv", 1)],
     guesses = [(r'([^\n,"]+|[ \t]*"(""|[^"])*"[ \t]*)(,([^\n,"]+|[ \t]*"(""|[^"])*"[ \t]*))+(\n|$)', 0.1)],
@@ -72,7 +76,8 @@ register("parce.lang.csv.Csv.root",
 
 register("parce.lang.docbook.DocBook.root",
     name = "DocBook",
-    desc = "DocBook XMl/SGML computer documentation schema",
+    desc = "DocBook XMl/SGML computer documentation",
+    section = "Markup",
     filenames = [("*.docbook", 1), ("*.dbk", 1), ("*.xml", .1)],
     mimetypes = [("text/docbook", 1), ("application/sgml", .1)],
     guesses = [(r'^\s*<\?xml ', .2), (r'OASIS.*?DocBook', 1), (r'<book\b', .8)],
@@ -81,6 +86,7 @@ register("parce.lang.docbook.DocBook.root",
 register("parce.lang.xml.Dtd.root",
     name = "DTD",
     desc = "Document Type Definition",
+    section = "Markup",
     filenames = [("*.dtd", 1)],
     mimetypes = [("application/xml-dtd", 1)],
     guesses = [(r'<!ENTITY\b', 0.5)],
@@ -89,6 +95,7 @@ register("parce.lang.xml.Dtd.root",
 register("parce.lang.ini.Ini.root",
     name = "INI",
     desc = "INI file format",
+    section = "Other",
     aliases = ["config"],
     filenames = [("*.ini", 1), ("*.cfg", 0.6), ("*.conf", 0.6)],
     mimetypes = [("text/plain", 0.1)],
@@ -98,6 +105,7 @@ register("parce.lang.ini.Ini.root",
 register("parce.lang.javascript.JavaScript.root",
     name = "JavaScript",
     desc = "JavaScript programming language",
+    section = "Scripting",
     aliases = ["js", "ecmascript"],
     filenames = [("*.js", 1), ("*.jsm", .8)],
     mimetypes = [("application/javascript", 1), ("application/x-javascript", 1),
@@ -107,6 +115,7 @@ register("parce.lang.javascript.JavaScript.root",
 register("parce.lang.json.Json.root",
     name = "JSON",
     desc = "JavaScript Object Notation format",
+    section = "Other",
     filenames = [("*.json", 1)],
     mimetypes = [("application/json", 1)],
     guesses = [(r'^\s*\{\s*"\w+"\s*:', .7)],
@@ -114,7 +123,8 @@ register("parce.lang.json.Json.root",
 
 register("parce.lang.html.Html.root",
     name = "HTML",
-    desc = "HTML (4 or 5)",
+    desc = "HTML 4 or 5",
+    section = "Markup",
     filenames = [("*.html", 1), ("*.htm", 1)],
     mimetypes = [("text/html", 1)],
     guesses = [
@@ -128,6 +138,7 @@ register("parce.lang.html.Html.root",
 register("parce.lang.tex.Latex.root",
     name = "LaTeX",
     desc = "TeX and LaTeX",
+    section = "Markup",
     aliases = ["TeX"],
     filenames = [("*.tex", 1), ("*.sty", .8), ("*.cls", .1)],
     mimetypes = [("text/x-latex", .8), ("application/x-latex", .8)],
@@ -136,7 +147,8 @@ register("parce.lang.tex.Latex.root",
 
 register("parce.lang.lilypond.LilyPond.root",
     name = "LilyPond",
-    desc = "LilyPond music typesetter",
+    desc = "LilyPond music",
+    section = "Music",
     filenames = [("*.ly", 1), ("*.ily", .8), ("*.lyi", .5)],
     mimetypes = [("text/x-lilypond", .8)],
     guesses = [
@@ -168,6 +180,7 @@ register("parce.lang.numbers.Nederlands.root",
 register("parce.lang.python.Python.root",
     name = "Python",
     desc = "Python programming language",
+    section = "Scripting",
     filenames = [("*.py", 1)],
     mimetypes = [("text/x-python", .8)],
     guesses = [(r'^#!.{,20}python', .8), (r'\bimport\s+[a-z]+\b', .3)],
@@ -176,12 +189,14 @@ register("parce.lang.python.Python.root",
 register("parce.lang.python.PythonConsole.root",
     name = "Python Console",
     desc = "Python console session",
+    section = "Scripting",
     guesses = [(r'^>>> ', .3)],
 )
 
 register("parce.lang.tcl.Tcl.root",
     name = "Tcl",
     desc = "Tool command language",
+    section = "Scripting",
     filenames = [("*.tcl", 1)],
     mimetypes = [("text/tcl", .8), ("text/x-tcl", .8), ("text/x-script.tcl", .8)],
     guesses = [(r'^#!.*?(wi|tcl)sh', .8), (r'^namespace eval', .1)],
@@ -190,6 +205,7 @@ register("parce.lang.tcl.Tcl.root",
 register("parce.lang.texinfo.Texinfo.root",
     name = "Texinfo",
     desc = "GNU Texinfo",
+    section = "Markup",
     filenames = [("*.texi", 1), ("*.texinfo", 1), ("*.txi", .5), ("*.itexi", .3), ("*.tex", .1)],
     mimetypes = [("application/x-texinfo", 1)],
     guesses = [(r'^@c\b', .8), (r'^\\input\s+texinfo\b', 1)],
@@ -198,6 +214,7 @@ register("parce.lang.texinfo.Texinfo.root",
 register("parce.lang.troff.Troff.root",
     name = "Troff",
     desc = "Troff document processing language",
+    section = "Markup",
     aliases = ["groff", "nroff", "roff", "man"],
     filenames = [("*.man", .8), ("*.[12345678]", .8)],
     mimetypes = [("application/x-troff", .8), ("text/troff", .8)],
@@ -207,6 +224,7 @@ register("parce.lang.troff.Troff.root",
 register("parce.lang.scheme.Scheme.root",
     name = "Scheme",
     desc = "Scheme programming language",
+    section = "Scripting",
     aliases = ["guile"],
     filenames = [("*.scm", 1)],
     mimetypes = [("text/x-script.scheme", 1), ("text/x-script.guile", 1)],
@@ -216,6 +234,7 @@ register("parce.lang.scheme.Scheme.root",
 register("parce.lang.toml.Toml.root",
     name = "TOML",
     desc = "Tom's Obvious, Minimal Language",
+    section = "Other",
     filenames = [("*.toml", 1), ("*.tml", .5)],
     mimetypes = [("application/toml", 1)],
     guesses = [(r'^\s*\[\\w+(\.(w+))*\]', 0.5), (r"^\s*#", 0.05)],
@@ -223,7 +242,8 @@ register("parce.lang.toml.Toml.root",
 
 register("parce.lang.html.XHtml.root",
     name = "XHTML",
-    desc = "HTML that is valid XML",
+    desc = "XHTML strict",
+    section = "Markup",
     filenames = [("*.html", 1), ("*.htm", 1), ("*.xhtml", 1)],
     mimetypes = [("text/html", 1), ("application/xhtml+xml", 1)],
     guesses = [
@@ -237,9 +257,20 @@ register("parce.lang.html.XHtml.root",
 register("parce.lang.xml.Xml.root",
     name = "XML",
     desc = "Extensible Markup Language",
+    section = "Markup",
     aliases = ['sgml'],
     filenames = [("*.xml", 1)],
     mimetypes = [("text/xml", 1), ("application/xml", 1)],
     guesses = [(r'^\s*<\?xml ', 1)],
 )
 
+register("parce.lang.xslt.Xslt.root",
+    name = "XSLT",
+    desc = "Extensible Stylesheet Language Transformations",
+    section = "Markup",
+    aliases = ['xslt', 'xsl'],
+    filenames = [("*.xsl", 1), ("*.xslt", 1), ("*.xpl", .5)],
+    mimetypes = [("application/xsl+xml", 1), ("application/xslt+xml", 1), ("text/xsl", 1), ("text/xslt", 1)],
+    guesses = [(r'^\s*<\?xml ', .1), (r'<xsl:stylesheet\b', 1)],
+)
+
