@@ -34,6 +34,7 @@ from parce.rule import (
     MATCH, TEXT, arg, bygroup, call, dselect, findmember, ifarg, ifeq, ifgroup,
     ifmember, select, using, words)
 from parce.indent import Indent, ALIGN, INDENT, DEDENT, NO_DEDENT
+from parce import docio
 
 from . import lilypond_words
 
@@ -661,3 +662,10 @@ class LilyPondIndent(Indent):
             else:
                 yield NO_DEDENT
 
+
+class LilyPondIO(docio.IO):
+    """IO handling."""
+    def default_encoding(self):
+        """Return "utf-8" by default."""
+        return "utf-8"
+
